@@ -10,7 +10,7 @@ cmake -LAH -G"Ninja" \
   -DCMAKE_INSTALL_PREFIX=${PREFIX} \
   -DCMAKE_INSTALL_LIBDIR=lib \
   -DCMAKE_BUILD_TYPE=Release \
-  -DCATCH_ENABLE_WERROR=OFF \
+  -DCATCH_ENABLE_WERROR:BOOL=OFF \
   ..
 
 # build and install
